import styles from "./card.module.css";
import Image from "next/image";
import Link from "next/link";
import Icons from "../icons/page";
import PropTypes from "prop-types";

const Card = ({
  title,
  description,
  blogImage,
  publishedOn,
  author,
  readingTime,
}) => {
  console.log(blogImage);
  return (
    <div className={styles.card}>
      <Link prefetch={false} href="#">
        <Image
          className={styles.img}
          src={blogImage.image}
          height={blogImage.height}
          width={blogImage.width}
          quality={100}
          alt="cardimage"
        />
      </Link>
      <div className={styles["card-content"]}>
        <Link prefetch={false} href="#" className={styles.title}>
          <p>{title}</p>
        </Link>
        <p className={styles.description}>{description}</p>
        <div className={styles.authorcontainer}>
          <div className={styles.cardbottom}>
            <Image
              className={styles.img}
              src={author.image}
              quality={100}
              alt="authorImg"
            />
            <div className={styles.authordescription}>
              <p>{author.name}</p>
              <div className={styles["author-desc"]}>
                {publishedOn}
                <span className={styles.icon}>
                  <Icons name="clock" />
                  {readingTime}
                </span>
              </div>
            </div>
          </div>
        </div>
      </div>
    </div>
  );
};
Card.propTypes = {
  title: PropTypes.string,
  description: PropTypes.string,
  blogImage: PropTypes.shape({
    image: PropTypes.string,
    height: PropTypes.number,
    width: PropTypes.number,
  }),
  publishedon: PropTypes.string,
  author: PropTypes.shape({
    name: PropTypes.string,
    image: PropTypes.string, // Use PropTypes.string for images
  }),

  readingTime: PropTypes.string,
};

export default Card;
