import styles from "./header.module.css";
import Search from "../search/page";
import Icon from "../icons/page";
import { useTheme } from "../../../context";
import Link from "next/link";

function Header({ name, onThemeChange, onSearch, onClose }) {
  const { theme, toggleTheme } = useTheme();

  const handleTheme = () => {
    toggleTheme();
    onThemeChange(theme);
  };
  const handleSearch = (value) => {
    onSearch(value);
  };
  const handleClose = () => {
    onClose("");
  };
  return (
    <header className={styles.header}>
      <div className={styles.container}>
        <nav className={styles.navbar}>
          <Link className={styles["navbar-brand"]} href="/" prefetch={false}>
            <Icon name="newspaper" />
            <h2>{name}</h2>
          </Link>

          <div className={styles.search}>
            <Search onSearch={handleSearch} onClose={handleClose} />
          </div>

          <div onClick={handleTheme} className={styles.themelight}>
            <Icon name={theme == "light" ? "moon" : "sun"} />
            <span className={styles.mobilemenu}>
              <Icon name="hamburger" />
            </span>
          </div>
        </nav>
      </div>
    </header>
  );
}

export default Header;
